@@ -18,7 +18,6 @@ from distutils.version import StrictVersion
 import hashlib
 import logging
 import os
-import re
 import socket
 import ssl
 import textwrap
@@ -44,15 +43,14 @@ from ironicclient import exc
 #             http://specs.openstack.org/openstack/ironic-specs/specs/kilo/api-microversions.html # noqa
 #             for full details.
 DEFAULT_VER = '1.9'
-LAST_KNOWN_API_VERSION = 46
+LAST_KNOWN_API_VERSION = 56
 LATEST_VERSION = '1.{}'.format(LAST_KNOWN_API_VERSION)
 
 LOG = logging.getLogger(__name__)
 USER_AGENT = 'python-ironicclient'
 CHUNKSIZE = 1024 * 64  # 64kB
 
-_MAJOR_VERSION = 1
-API_VERSION = '/v%d' % _MAJOR_VERSION
+API_VERSION = '/v1'
 API_VERSION_SELECTED_STATES = ('user', 'negotiated', 'cached', 'default')
 
 
@@ -63,12 +61,10 @@ SENSITIVE_HEADERS = ('X-Auth-Token',)
 
 SUPPORTED_ENDPOINT_SCHEME = ('http', 'https')
 
-_API_VERSION_RE = re.compile(r'/+(v%d)?/*$' % _MAJOR_VERSION)
-
 
 def _trim_endpoint_api_version(url):
     """Trim API version and trailing slash from endpoint."""
-    return re.sub(_API_VERSION_RE, '', url)
+    return url.rstrip('/').rstrip(API_VERSION).rstrip('/')
 
 
 def _extract_error_json(body):
@@ -608,9 +604,6 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
                         'removed in Stein. Please use "endpoint_override" '
                         'instead.')
             self.endpoint = endpoint
-        if isinstance(kwargs.get('endpoint_override'), six.string_types):
-            kwargs['endpoint_override'] = _trim_endpoint_api_version(
-                kwargs['endpoint_override'])
 
         super(SessionClient, self).__init__(**kwargs)
 
@@ -627,8 +620,7 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
         # NOTE: conn is self.session for this class
         return conn.request(url, method, raise_exc=False,
                             user_agent=USER_AGENT,
-                            endpoint_filter=endpoint_filter,
-                            endpoint_override=self.endpoint_override)
+                            endpoint_filter=endpoint_filter)
 
     @with_retries
     def _http_request(self, url, method, **kwargs):
@@ -641,7 +633,10 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
         kwargs.setdefault('user_agent', USER_AGENT)
         kwargs.setdefault('auth', self.auth)
         if isinstance(self.endpoint_override, six.string_types):
-            kwargs.setdefault('endpoint_override', self.endpoint_override)
+            kwargs.setdefault(
+                'endpoint_override',
+                _trim_endpoint_api_version(self.endpoint_override)
+            )
 
         if getattr(self, 'os_ironic_api_version', None):
             kwargs['headers'].setdefault('X-OpenStack-Ironic-API-Version',
